==> citrine-0.9.5.tar.gz: citrine-0.9.5/i18n/uz/dictionary.h <==
#define CTR_DICT_CODEGEN_MAP_NEW                 "(Ro'yxat yangi) "
#define CTR_DICT_CODEGEN_MAP_PUT                 "qo’yish:"
#define CTR_DICT_CODEGEN_MAP_PUT_AT              " da:"
#define CTR_DICT_CODEGEN_ARRAY_NEW               "Qator yangi "
#define CTR_DICT_CODEGEN_ARRAY_NEW_PUSH          "Qator ← "
#define CTR_DICT_END_OF_LINE     "."
#define CTR_DICT_NIL              "Bo'sh"
#define CTR_DICT_BOOLEAN          "Boolean"
#define CTR_DICT_TRUE             "Rost"
#define CTR_DICT_FALSE            "Yolg’on"
#define CTR_DICT_NUMBER           "Raqam"
#define CTR_DICT_STRING           "Matn"
#define CTR_DICT_TASK       "Kod"
#define CTR_DICT_OBJECT           "Ob’ekt"
#define CTR_DICT_ARRAY_OBJECT      "Qator"
#define CTR_DICT_MAP_OBJECT       "Ro'yxat"
#define CTR_DICT_PROGRAM        "Dastur"
#define CTR_DICT_FILE             "Fayl"
#define CTR_DICT_MOMENT       "Moment"
#define CTR_DICT_VAR_ICON        "☞"
#define CTR_DICT_ME_ICON         "⛏"
#define CTR_DICT_MY_ICON         "⚿"
#define CTR_DICT_BULLET          "•"
#define CTR_DICT_SYMBOL_EQUALS   "="
#define CTR_DICT_PLUS            "+"
#define CTR_DICT_MINUS   	     "-"
#define CTR_DICT_MULTIPLIER   	 "×"
#define CTR_DICT_DIVISION   	 "÷"
#define CTR_DICT_GREATER   	     ">"
#define CTR_DICT_LESS   	     "<"
#define CTR_DICT_AT_SYMBOL       "?" 
#define CTR_DICT_PEN_ICON        "✎"
#define CTR_DICT_NEW_ARRAY_AND_PUSH_SYMBOL       "←"
#define CTR_DICT_GREATER_OR_EQUAL_SYMBOL         "≥"
#define CTR_DICT_LESS_OR_EQUAL_SYMBOL            "≤"
#define CTR_DICT_UNEQUALS_SYMBOL                 "≠"
#define CTR_DICT_NEW              "yangi"
#define CTR_DICT_EQUALS           "teng:"
#define CTR_DICT_AND              "va:"
#define CTR_DICT_OR               "yoki:"
#define CTR_DICT_MODULO           "modulo:"
#define CTR_DICT_NOR              "ham:"
#define CTR_DICT_ONDO             "agar:bo’lsa:"
#define CTR_DICT_TYPE             "turi"
#define CTR_DICT_ISNIL            "bo'sh?"
#define CTR_DICT_MYSELF           "o’zim"
#define CTR_DICT_DO               "qilmoq"
#define CTR_DICT_DONE             "bajarildi"
#define CTR_DICT_IFFALSE          "yolg’on:"
#define CTR_DICT_IFTRUE           "haqiqiy:"
#define CTR_DICT_WHILE            "vaqt:"
#define CTR_DICT_MESSAGEARGS      "xabar:dalillar:"
#define CTR_DICT_MESSAGE          "xabar:"
#define CTR_DICT_LEARN            "o’rganish:anglatadi:"
#define CTR_DICT_BREAK            "tanaffus"
#define CTR_DICT_CONTINUE         "davom eting"
#define CTR_DICT_ELSE             "yana:"
#define CTR_DICT_NOT              "emas"
#define CTR_DICT_TONUMBER         "raqam"
#define CTR_DICT_ITONUMBER        "xalqaro raqam"
#define CTR_DICT_TOSTRING         "matn"
#define CTR_DICT_CHAR_AT_SET      "belgi:"
#define CTR_DICT_EITHEROR         "yoxi:yoki:"
#define CTR_DICT_BY_SET       	  "tomonidan:"
#define CTR_DICT_FLOOR            "past"
#define CTR_DICT_CEIL             "yuqori"
#define CTR_DICT_ROUND            "dumaloq"
#define CTR_DICT_ABS              "mutlaq"
#define CTR_DICT_SQRT             "kvadrat ildiz"
#define CTR_DICT_POWER            "quvvat:"
#define CTR_DICT_MIN              "eng kam"
#define CTR_DICT_MAX              "maksimal"
#define CTR_DICT_ODD   	          "toq?"
#define CTR_DICT_EVEN   	      "juft?"
#define CTR_DICT_POS   	          "ijobiy?"
#define CTR_DICT_NEG   	          "salbiymi?"
#define CTR_DICT_TOBOOL           "mantiqiy"
#define CTR_DICT_RANDOM_NUM_BETWEEN          "orasida:va:"
#define CTR_DICT_LENGTH	          "uzunligi"
#define CTR_DICT_FROM_LENGTH	  "ushbudan:boshlab:"
#define CTR_DICT_TRIM	          "atrofdagi bo’shliqlarni olib tashlang"
#define CTR_DICT_AT               "da:"
#define CTR_DICT_POSITION_SET     "lavozimi:"
#define CTR_DICT_INDEX_OF         "topish:"
#define CTR_DICT_LAST_INDEX_OF	  "oxirgi:"
#define CTR_DICT_REPLACE_WITH	  "o’rniga:bilan:"
#define CTR_DICT_SPLIT	          "split:"
#define CTR_DICT_SKIP             "ofset:"
#define CTR_DICT_RUN              "yugurish"
#define CTR_DICT_APPLY_TO         "murojaat qilish:"
#define CTR_DICT_APPLY_TO_AND     "qo’llash:va:"
#define CTR_DICT_VALUE_SET        "sozlangan:qiymat:"
#define CTR_DICT_ERROR	          "xato:"
#define CTR_DICT_CATCH            "ushlash:"
#define CTR_DICT_PUSH_SYMBOL     ";"
#define CTR_DICT_SHIFT            "birinchi ob'ektni oling"
#define CTR_DICT_COUNT            "hisoblash"
#define CTR_DICT_JOIN             "qo’shilish:"
#define CTR_DICT_POP              "oxirgi ob'ektni oling"
#define CTR_DICT_SORT             "saralash:"
#define CTR_DICT_PUT_AT           "qo’yish:da:"
#define CTR_DICT_MAP              "xaritasi:"
#define CTR_DICT_EACH             "har biri:"
#define CTR_DICT_WRITE            "yozish:"
#define CTR_DICT_PATH             "yo’l"
#define CTR_DICT_READ             "o’qing"
#define CTR_DICT_APPEND           "qo'shimcha:"
#define CTR_DICT_PREPEND          "prefiks:"
#define CTR_DICT_EXISTS           "mavjud"
#define CTR_DICT_SIZE             "hajmi"
#define CTR_DICT_DELETE           "o’chirish"
#define CTR_DICT_USE_SET          "foydalanish:"
#define CTR_DICT_ARRAY             "qator:"
#define CTR_DICT_END              "oxiri"
#define CTR_DICT_ARGUMENT	      "dalil:"
#define CTR_DICT_ARGUMENT_COUNT	  "dalillar"
#define CTR_DICT_WAIT_FOR_PASSW	  "parol so'rang"
#define CTR_DICT_WAIT_FOR_INPUT	  "so’rash"
#define CTR_DICT_INPUT            "kiritish"
#define CTR_DICT_FLUSH            "flush"
#define CTR_DICT_WAIT             "kutmoq:"
#define CTR_DICT_TIME	          "vaqt"
#define CTR_DICT_RESPOND_TO       "javob bering:"
#define CTR_DICT_RESPOND_TO_AND   "javob bering:va:"
#define CTR_DICT_SHELL            "tizim Buyrug'i:"
#define CTR_DICT_SWEEP            "toza xotira"
#define CTR_DICT_MEMORY_LIMIT	  "xotira:"
#define CTR_DICT_MEMORY           "xotira"
#define CTR_DICT_GC_MODE             "tozalik:"
#define CTR_DICT_HASH_WITH_KEY    "xesh:"
#define CTR_DICT_CHARACTERS       "belgilar"
#define CTR_DICT_QUALIFIER_SET          "malakasi:"
#define CTR_DICT_QUALIFIER    "malaka"
#define CTR_DICT_NEW_SET          "yangi:"
#define CTR_DICT_HOUR             "soat"
#define CTR_DICT_HOUR_SET         "soat:"
#define CTR_DICT_MINUTE_SET       "daqiqa:"
#define CTR_DICT_MINUTE           "daqiqa"
#define CTR_DICT_SECOND_SET       "ikkinchi:"
#define CTR_DICT_SECOND           "ikkinchi"
#define CTR_DICT_DAY              "kun"
#define CTR_DICT_DAY_SET          "kun:"
#define CTR_DICT_WEEK             "hafta"
#define CTR_DICT_WEEK_SET         "hafta:"
#define CTR_DICT_MONTH            "oy"
#define CTR_DICT_MONTH_SET        "oy:"
#define CTR_DICT_YEAR             "yil"
#define CTR_DICT_RAW              "xom"
#define CTR_DICT_YEAR_SET         "yil:"
#define CTR_DICT_WEEK_DAY         "ish kuni"
#define CTR_DICT_YEAR_DAY         "yilning kuni"
#define CTR_DICT_ZONE             "zonasi"
#define CTR_DICT_ZONE_SET         "zonasi:"
#define CTR_DICT_ADD_SET          "qo’shish:"
#define CTR_DICT_SUBTRACT_SET     "ayirish:"
#define CTR_DICT_MULTIPLIER_SET   "ko’paytirish:"
#define CTR_DICT_DIVIDER_SET      "bo’lingan:"
#define CTR_DICT_LAST             "oxirgi"
#define CTR_DICT_FIRST            "birinchi"
#define CTR_DICT_SECOND_LAST      "ikkinchi oxirgi"
#define CTR_DICT_FILL_WITH        "to’ldiring:bilan:"
#define CTR_DICT_SPLICE           "almashtirish:uzunligi:bilan:bilan"
#define CTR_DICT_VALUES           "qiymatlar"
#define CTR_DICT_ENTRIES          "yozuvlar"
#define CTR_DICT_COMPARE_SET      "solishtiring:"
#define CTR_DICT_HAS              "ega:"
#define CTR_DICT_COPY             "nusxa ko’chirish"
#define CTR_DICT_CASE_DO          "case:do:"
#define CTR_DICT_STOP             "to’xta"
#define CTR_DICT_ASCII_UPPER_CASE                 "katta harf"
#define CTR_DICT_ASCII_LOWER_CASE                 "kichik harf"
#define CTR_DICT_CONTAINS                         "o’z ichiga oladi:"
#define CTR_DICT_APPLY_TO_AND_AND                 "qo’llash:va:va:"
#define CTR_DICT_ENVIRONMENT_VARIABLE             "sozlama:"
#define CTR_DICT_SET_ENVIRONMENT_VARIABLE         "sozlama:qiymat:"
#define CTR_DICT_RESPOND_TO_AND_AND               "javob bering:va:va:"
#define CTR_DICT_RESPOND_TO_AND_AND_AND           "javob:va:va:va:"
#define CTR_DICT_CURRENT_TASK                       "ushbu kod bloki"
#define CTR_DICT_NUM_DEC_SEP                     ","
#define CTR_DICT_NUM_THO_SEP                     "."
#define CTR_DICT_QUOT_OPEN                       "«"
#define CTR_DICT_QUOT_CLOSE                      "»"
#define CTR_DICT_MESSAGE_CHAIN                   ","
#define CTR_DICT_ASSIGN                          "≔"
#define CTR_DICT_PAREN_OPEN                      "("
#define CTR_DICT_PAREN_CLOSE                     ")"
#define CTR_DICT_BLOCK_START                     "{"
#define CTR_DICT_BLOCK_END                       "}"
#define CTR_DICT_PARAMETER_PREFIX                ":"
#define CTR_DICT_RETURN                          "↲"
#define CTR_DICT_CODE                            "code"
#define CTR_DICT_PROCEDURE                       "tartibi"
#define CTR_DICT_TOOBJECT        "ob’ekt"
#define CTR_DICT_PATH_OBJECT "Fayl joylashuvi"
#define CTR_DICT_CMD_OBJECT  "Yo'riqnoma"
#define CTR_DICT_RECURSIVE "rekursiv"

==> citrine-0.9.6.tar.gz: citrine-0.9.6/i18n/uz/dictionary.h <==
#define CTR_DICT_CODEGEN_MAP_NEW                 "(Ro'yxat yangi) "
#define CTR_DICT_CODEGEN_MAP_PUT                 "qo'yish:"
#define CTR_DICT_CODEGEN_MAP_PUT_AT              " da:"
#define CTR_DICT_CODEGEN_ARRAY_NEW               "Qator yangi "
#define CTR_DICT_CODEGEN_ARRAY_NEW_PUSH          "Qator ← "
#define CTR_DICT_END_OF_LINE     "."
#define CTR_DICT_NIL              "Bo'sh"
#define CTR_DICT_BOOLEAN          "Boolean"
#define CTR_DICT_TRUE             "Rost"
#define CTR_DICT_FALSE            "Yolg'on"
#define CTR_DICT_NUMBER           "Raqam"
#define CTR_DICT_STRING           "Matn"
#define CTR_DICT_TASK       "Kod"
#define CTR_DICT_OBJECT           "Ob'ekt"
#define CTR_DICT_ARRAY_OBJECT      "Qator"
#define CTR_DICT_MAP_OBJECT       "Ro'yxat"
#define CTR_DICT_PROGRAM        "Dastur"
#define CTR_DICT_FILE             "Fayl"
#define CTR_DICT_MOMENT       "Lahza"
#define CTR_DICT_VAR_ICON        "☞"
#define CTR_DICT_ME_ICON         "⛏"
#define CTR_DICT_MY_ICON         "⚿"
#define CTR_DICT_BULLET          "•"
#define CTR_DICT_SYMBOL_EQUALS   "="
#define CTR_DICT_PLUS            "+"
#define CTR_DICT_MINUS   	     "-"
#define CTR_DICT_MULTIPLIER   	 "×"
#define CTR_DICT_DIVISION   	 "÷"
#define CTR_DICT_GREATER   	     ">"
#define CTR_DICT_LESS   	     "<"
#define CTR_DICT_AT_SYMBOL       "?" 
#define CTR_DICT_PEN_ICON        "✎"
#define CTR_DICT_NEW_ARRAY_AND_PUSH_SYMBOL       "←"
#define CTR_DICT_GREATER_OR_EQUAL_SYMBOL         "≥"
#define CTR_DICT_LESS_OR_EQUAL_SYMBOL            "≤"
#define CTR_DICT_UNEQUALS_SYMBOL                 "≠"
#define CTR_DICT_NEW              "yangi"
#define CTR_DICT_EQUALS           "teng:"
#define CTR_DICT_AND              "va:"
#define CTR_DICT_OR               "yoki:"
#define CTR_DICT_MODULO           "modul:"
#define CTR_DICT_NOR              "ham:"
#define CTR_DICT_ONDO             "agar:bo'lsa:"
#define CTR_DICT_TYPE             "turi"
#define CTR_DICT_ISNIL            "bo'sh?"
#define CTR_DICT_MYSELF           "o'zim"
#define CTR_DICT_DO               "qilmoq"
#define CTR_DICT_DONE             "bajarildi"
#define CTR_DICT_IFFALSE          "yolg'on:"
#define CTR_DICT_IFTRUE           "haqiqiy:"
#define CTR_DICT_WHILE            "vaqt:"
#define CTR_DICT_MESSAGEARGS      "xabar:dalillar:"
#define CTR_DICT_MESSAGE          "xabar:"
#define CTR_DICT_LEARN            "o'rganish:anglatadi:"
#define CTR_DICT_BREAK            "tanaffus"
#define CTR_DICT_CONTINUE         "davom eting"
#define CTR_DICT_ELSE             "yana:"
#define CTR_DICT_NOT              "emas"
#define CTR_DICT_TONUMBER         "raqam"
#define CTR_DICT_ITONUMBER        "xalqaro raqam"
#define CTR_DICT_TOSTRING         "matn"
#define CTR_DICT_CHAR_AT_SET      "belgi:"
#define CTR_DICT_EITHEROR         "yoxi:yoki:"
#define CTR_DICT_BY_SET       	  "tomonidan:"
#define CTR_DICT_FLOOR            "past"
#define CTR_DICT_CEIL             "yuqori"
#define CTR_DICT_ROUND            "dumaloq"
#define CTR_DICT_ABS              "mutlaq"
#define CTR_DICT_SQRT             "kvadrat ildiz"
#define CTR_DICT_POWER            "quvvat:"
#define CTR_DICT_MIN              "eng kam"
#define CTR_DICT_MAX              "maksimal"
#define CTR_DICT_ODD   	          "toq?"
#define CTR_DICT_EVEN   	      "juft?"
#define CTR_DICT_POS   	          "ijobiy?"
#define CTR_DICT_NEG   	          "salbiymi?"
#define CTR_DICT_TOBOOL           "mantiqiy"
#define CTR_DICT_RANDOM_NUM_BETWEEN          "orasida:va:"
#define CTR_DICT_LENGTH	          "uzunligi"
#define CTR_DICT_FROM_LENGTH	  "ushbudan:boshlab:"
#define CTR_DICT_TRIM	          "atrofdagi bo'shliqlarni olib tashlang"
#define CTR_DICT_AT               "da:"
#define CTR_DICT_POSITION_SET     "lavozimi:"
#define CTR_DICT_INDEX_OF         "topish:"
#define CTR_DICT_LAST_INDEX_OF	  "oxirgi:"
#define CTR_DICT_REPLACE_WITH	  "o'rniga:bilan:"
#define CTR_DICT_SPLIT	          "split:"
#define CTR_DICT_SKIP             "ofset:"
#define CTR_DICT_RUN              "yugurish"
#define CTR_DICT_APPLY_TO         "murojaat qilish:"
#define CTR_DICT_APPLY_TO_AND     "qo'llash:va:"
#define CTR_DICT_VALUE_SET        "sozlangan:qiymat:"
#define CTR_DICT_ERROR	          "xato:"
#define CTR_DICT_CATCH            "ushlash:"
#define CTR_DICT_PUSH_SYMBOL     ";"
#define CTR_DICT_SHIFT            "birinchi ob'ektni oling"
#define CTR_DICT_COUNT            "hisoblash"
#define CTR_DICT_JOIN             "qo'shilish:"
#define CTR_DICT_POP              "oxirgi ob'ektni oling"
#define CTR_DICT_SORT             "saralash:"
#define CTR_DICT_PUT_AT           "qo'yish:da:"
#define CTR_DICT_MAP              "xaritasi:"
#define CTR_DICT_EACH             "har biri:"
#define CTR_DICT_WRITE            "yozish:"
#define CTR_DICT_PATH             "yo'l"
#define CTR_DICT_READ             "o'qing"
#define CTR_DICT_APPEND           "qo'shimcha:"
#define CTR_DICT_PREPEND          "prefiks:"
#define CTR_DICT_EXISTS           "mavjud"
#define CTR_DICT_SIZE             "hajmi"
#define CTR_DICT_DELETE           "o'chirish"
#define CTR_DICT_USE_SET          "foydalanish:"
#define CTR_DICT_ARRAY             "qator:"
#define CTR_DICT_END              "oxiri"
#define CTR_DICT_ARGUMENT	      "dalil:"
#define CTR_DICT_ARGUMENT_COUNT	  "dalillar"
#define CTR_DICT_WAIT_FOR_PASSW	  "parol so'rang"
#define CTR_DICT_WAIT_FOR_INPUT	  "so'rash"
#define CTR_DICT_INPUT            "kiritish"
#define CTR_DICT_FLUSH            "flush"
#define CTR_DICT_WAIT             "kutmoq:"
#define CTR_DICT_TIME	          "vaqt"
#define CTR_DICT_RESPOND_TO       "javob bering:"
#define CTR_DICT_RESPOND_TO_AND   "javob bering:va:"
#define CTR_DICT_SHELL            "tizim Buyrug'i:"
#define CTR_DICT_SWEEP            "toza xotira"
#define CTR_DICT_MEMORY_LIMIT	  "xotira:"
#define CTR_DICT_MEMORY           "xotira"
#define CTR_DICT_GC_MODE             "tozalik:"
#define CTR_DICT_HASH_WITH_KEY    "xesh:"
#define CTR_DICT_CHARACTERS       "belgilar"
#define CTR_DICT_QUALIFIER_SET          "malakasi:"
#define CTR_DICT_QUALIFIER    "malaka"
#define CTR_DICT_NEW_SET          "yangi:"
#define CTR_DICT_HOUR             "soat"
#define CTR_DICT_HOUR_SET         "soat:"
#define CTR_DICT_MINUTE_SET       "daqiqa:"
#define CTR_DICT_MINUTE           "daqiqa"
#define CTR_DICT_SECOND_SET       "ikkinchi:"
#define CTR_DICT_SECOND           "ikkinchi"
#define CTR_DICT_DAY              "kun"
#define CTR_DICT_DAY_SET          "kun:"
#define CTR_DICT_WEEK             "hafta"
#define CTR_DICT_WEEK_SET         "hafta:"
#define CTR_DICT_MONTH            "oy"
#define CTR_DICT_MONTH_SET        "oy:"
#define CTR_DICT_YEAR             "yil"
#define CTR_DICT_RAW              "xom"
#define CTR_DICT_YEAR_SET         "yil:"
#define CTR_DICT_WEEK_DAY         "ish kuni"
#define CTR_DICT_YEAR_DAY         "yilning kuni"
#define CTR_DICT_ZONE             "zonasi"
#define CTR_DICT_ZONE_SET         "zonasi:"
#define CTR_DICT_ADD_SET          "qo'shish:"
#define CTR_DICT_SUBTRACT_SET     "ayirish:"
#define CTR_DICT_MULTIPLIER_SET   "ko'paytirish:"
#define CTR_DICT_DIVIDER_SET      "bo'lingan:"
#define CTR_DICT_LAST             "oxirgi"
#define CTR_DICT_FIRST            "birinchi"
#define CTR_DICT_SECOND_LAST      "ikkinchi oxirgi"
#define CTR_DICT_FILL_WITH        "to'ldiring:bilan:"
#define CTR_DICT_SPLICE           "almashtirish:uzunligi:bilan:bilan"
#define CTR_DICT_VALUES           "qiymatlar"
#define CTR_DICT_ENTRIES          "yozuvlar"
#define CTR_DICT_COMPARE_SET      "solishtiring:"
#define CTR_DICT_HAS              "ega:"
#define CTR_DICT_COPY             "nusxa ko'chirish"
#define CTR_DICT_CASE_DO          "ish:qil:"
#define CTR_DICT_STOP             "to'xta"
#define CTR_DICT_ASCII_UPPER_CASE                 "katta harf"
#define CTR_DICT_ASCII_LOWER_CASE                 "kichik harf"
#define CTR_DICT_CONTAINS                         "o'z ichiga oladi:"
#define CTR_DICT_APPLY_TO_AND_AND                 "qo'llash:va:va:"
#define CTR_DICT_ENVIRONMENT_VARIABLE             "sozlama:"
#define CTR_DICT_SET_ENVIRONMENT_VARIABLE         "sozlama:qiymat:"
#define CTR_DICT_RESPOND_TO_AND_AND               "javob bering:va:va:"
#define CTR_DICT_RESPOND_TO_AND_AND_AND           "javob:va:va:va:"
#define CTR_DICT_CURRENT_TASK                       "ushbu kod bloki"
#define CTR_DICT_NUM_DEC_SEP                     ","
#define CTR_DICT_NUM_THO_SEP                     "."
#define CTR_DICT_QUOT_OPEN                       "«"
#define CTR_DICT_QUOT_CLOSE                      "»"
#define CTR_DICT_MESSAGE_CHAIN                   ","
#define CTR_DICT_ASSIGN                          "≔"
#define CTR_DICT_PAREN_OPEN                      "("
#define CTR_DICT_PAREN_CLOSE                     ")"
#define CTR_DICT_BLOCK_START                     "{"
#define CTR_DICT_BLOCK_END                       "}"
#define CTR_DICT_PARAMETER_PREFIX                ":"
#define CTR_DICT_RETURN                          "↲"
#define CTR_DICT_CODE                            "code"
#define CTR_DICT_PROCEDURE                       "tartibi"
#define CTR_DICT_TOOBJECT        "ob'ekt"
#define CTR_DICT_PATH_OBJECT "Fayl joylashuvi"
#define CTR_DICT_CMD_OBJECT  "Yo'riqnoma"
#define CTR_DICT_RECURSIVE "rekursiv"
